from inductiva.client.paths.tasks_task_id.get import ApiForget
from inductiva.client.paths.tasks_task_id.delete import ApiFordelete


class TasksTaskId(
        ApiForget,
        ApiFordelete,
):
    pass
